.. py:currentmodule:: rubin_scheduler.data

.. _data-download:

=============
Data Download
=============

The `rubin_scheduler.data` module provides scripts to download data required to run the scheduler, as well as to check the expected versions of the data.
It also provides a utility to interpret the location of $RUBIN_SIM_DATA_DIR, checking both $HOME/rubin_sim_data and the environment variable $RUBIN_SIM_DATA_DIR and returning the appropriate path.
